@@ -36,8 +36,6 @@ run_tests() {
 
 prepare_system() {
     #yum install -y zlib-devel
-    # Remove Python 2.6 symlinks
-    rm -f /opt/python/cp26*
     echo "Python versions found: $(cd /opt/python && echo cp* | sed -e 's|[^ ]*-||g')"
 }
 
